@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package PDL::Graphics::Prima;
-our $VERSION = 0.05;
+our $VERSION = 0.07;
 
 package Prima::Plot;
 use PDL::Lite;
@@ -143,16 +143,23 @@ sub init {
 	
 	# Create the x- and y-axis objects, overriding the owner and axis name
 	# properties if they are set in the profile.
-	$self->{x} = PDL::Graphics::Prima::Axis->create(
-		  %{$profile{x}}
-		, owner => $self
-		, name => 'x'
-		);
-	$self->{y} = PDL::Graphics::Prima::Axis->create(
-		  %{$profile{y}}
-		, owner => $self
-		, name => 'y'
-		);
+	for ('x', 'y') {
+		if (eval{$profile{$_}->isa('PDL::Graphics::Prima::Axis')}) {
+			$self->{$_} = $profile{$_};
+			$self->{$_}->owner($self);
+			$self->{$_}->name($_);
+		}
+		elsif (ref ($profile{$_}) eq 'HASH') {
+			$self->{$_} = PDL::Graphics::Prima::Axis->create(
+				%{$profile{$_}}
+				, owner => $self
+				, name => $_
+			);
+		}
+		else {
+			croak("Unable to create $_-axis from $profile{$_}");
+		}
+	}
 	
 	$self->{timer} = Prima::Timer->create(
 		timeout => $profile{replotDuration},
@@ -206,7 +213,8 @@ sub compute_min_max_for {
 	my ($self, $axis_name) = @_;
 	
 	# Special handling for x-axis stuff:
-	if ($axis_name eq 'x') {
+	my (undef, $y_max_is_auto) = $self->y->max;
+	if ($axis_name eq 'x' and $y_max_is_auto) {
 		# First perform all of this on y so that the edge requirements are
 		# correctly computed for x-calculations later.
 		
@@ -282,6 +290,10 @@ sub collect_collated_min_max_for {
 	return ($trimmed_minima, $trimmed_maxima);
 }
 
+# Given a collated set of mininam and maxima (from collect_collated_min_max_for)
+# this function determines that minimum and maximum necessary for viewing *all*
+# the data.
+
 sub pair_down_collation {
 	my ($self, $axis_name, $trimmed_minima, $trimmed_maxima) = @_;
 	
@@ -298,6 +310,9 @@ sub pair_down_collation {
 	# real pixel extent is reduced by the requested pixel padding:
 	my $pixel_extent = $self->get_pixel_extent_for($axis_name);
 	my $virtual_pixel_extent = $pixel_extent - $min_pix - $max_pix;
+	# working here - come up with something better than just croaking.
+	die "Internal error: virtual pixel extent is non-positive"
+		if $virtual_pixel_extent <= 0;
 	# min_data and max_data are the actual min and max values of the data
 	# that are supposed to fit within the virtual pixel extent.
 	my ($min_data, $max_data) = ($trimmed_minima->at(0,2), $trimmed_maxima->at(0,2));
@@ -307,6 +322,8 @@ sub pair_down_collation {
 		, -$min_pix/$virtual_pixel_extent);
 	my $max = $self->{$axis_name}->scaling->inv_transform($min_data, $max_data
 		, 1 + $max_pix/$virtual_pixel_extent);
+	# working here - come up with something better than just croaking.
+	die "Internal error: min ($min) is greater than max ($max)" if $min > $max;
 	
 	# It is possible that all the x-data or all the y-data are identical. In
 	# that case, this scheme would normally be degenerate and return nan,
